@@ -1,11 +1,8 @@
-// SPDX-FileCopyrightText: none
-// SPDX-License-Identifier: GPL-3.0-only
+// SPDX-FileCopyrightText: 2022 Plata Hill <plata.hill@kdemail.net>
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "program.h"
 
-#include "channel.h"
-#include "database.h"
-
 #include <QDebug>
 
 Program::Program(const ProgramData &data)
